cmd

package
v0.1.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(ctx context.Context) error

Execute runs the root command with the given context. It now returns an error instead of exiting directly.

func HasHelpFlag added in v0.0.2

func HasHelpFlag(args []string) bool

HasHelpFlag checks if any help-related flags are present in the arguments.

func InitializeAppContext added in v0.0.2

func InitializeAppContext(ctx context.Context, tempRoot *cobra.Command) (*app.ApplicationContext, error)

InitializeAppContext checks for help-related flags and initializes the ApplicationContext accordingly. It returns an error instead of exiting directly.

func NewRootCmd

func NewRootCmd(appCtx *app.ApplicationContext) *cobra.Command

NewRootCmd creates a new root command with all subcommands attached

Types

This section is empty.

Directories

Path Synopsis
oke
bastion
Package bastion Command wiring and orchestration for "bastion creates".
Package bastion Command wiring and orchestration for "bastion creates".
vcn
shared

Jump to