domain

package
v0.1.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ErrNotFound is returned when a resource is not found.
	ErrNotFound = errors.New("not found")
)

Functions

func NewNotFoundError

func NewNotFoundError(resourceType, resourceName string) error

NewNotFoundError creates a new error indicating that a resource was not found.

Types

type ResourceTags

type ResourceTags map[string]string

ResourceTags represents a collection of resource tags.

Directories

Path Synopsis
network
vcn
storage

Jump to