vcn

package
v0.1.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewVCNListModel

func NewVCNListModel(v []domain.VCN) tui.Model

NewVCNListModel builds a TUI list for VCNs.

Types

type Adapter

type Adapter struct {
	// contains filtered or unexported fields
}

Adapter provides access to VCN-related OCI APIs. It is infra-layer and should be used by the service layer.

func NewAdapter

func NewAdapter(client core.VirtualNetworkClient) *Adapter

NewAdapter creates a new adapter instance.

func (*Adapter) GetDhcpOptions

func (a *Adapter) GetDhcpOptions(ctx context.Context, dhcpID string) (domain.DhcpOptions, error)

func (*Adapter) GetEnrichedVcn

func (a *Adapter) GetEnrichedVcn(ctx context.Context, vcnID string) (domain.VCN, error)

func (*Adapter) ListEnrichedVcns

func (a *Adapter) ListEnrichedVcns(ctx context.Context, compartmentID string) ([]domain.VCN, error)

ListEnrichedVcns lists VCNs and enriches them with all related resources in parallel.

func (*Adapter) ListVcns

func (a *Adapter) ListVcns(ctx context.Context, compartmentID string) ([]domain.VCN, error)

ListVcns lists all VCNs in a given compartment.

Jump to