Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
Execute runs the root command with the given context. It now returns an error instead of exiting directly.
func HasHelpFlag ¶ added in v0.0.2
HasHelpFlag checks if any help-related flags are present in the arguments.
func InitializeAppContext ¶ added in v0.0.2
func InitializeAppContext(ctx context.Context, tempRoot *cobra.Command) (*app.ApplicationContext, error)
InitializeAppContext checks for help-related flags and initializes the ApplicationContext accordingly. It returns an error instead of exiting directly.
func NewRootCmd ¶
func NewRootCmd(appCtx *app.ApplicationContext) *cobra.Command
NewRootCmd creates a new root command with all subcommands attached
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.