Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrNotFound is returned when a resource is not found. ErrNotFound = errors.New("not found") )
Functions ¶
func NewNotFoundError ¶
NewNotFoundError creates a new error indicating that a resource was not found.
Types ¶
type ResourceTags ¶
ResourceTags represents a collection of resource tags.
Click to show internal directories.
Click to hide internal directories.