Documentation
¶
Index ¶
- func NewVCNListModel(v []domain.VCN) tui.Model
- type Adapter
- func (a *Adapter) GetDhcpOptions(ctx context.Context, dhcpID string) (domain.DhcpOptions, error)
- func (a *Adapter) GetEnrichedVcn(ctx context.Context, vcnID string) (domain.VCN, error)
- func (a *Adapter) ListEnrichedVcns(ctx context.Context, compartmentID string) ([]domain.VCN, error)
- func (a *Adapter) ListVcns(ctx context.Context, compartmentID string) ([]domain.VCN, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Adapter ¶
type Adapter struct {
// contains filtered or unexported fields
}
Adapter provides access to VCN-related OCI APIs. It is infra-layer and should be used by the service layer.
func NewAdapter ¶
func NewAdapter(client core.VirtualNetworkClient) *Adapter
NewAdapter creates a new adapter instance.
func (*Adapter) GetDhcpOptions ¶
func (*Adapter) GetEnrichedVcn ¶
func (*Adapter) ListEnrichedVcns ¶
ListEnrichedVcns lists VCNs and enriches them with all related resources in parallel.
Click to show internal directories.
Click to hide internal directories.